@@ -129,7 +129,7 @@ class CurtailWindow(Adw.ApplicationWindow):
         result_item.error = error
         if not error:
             result_item.savings = str(round(100 - (result_item.new_size * 100 / result_item.size), 2)) + '%'
-            result_item.subtitle_label += ' -> ' + sizeof_fmt(result_item.new_size)
+            result_item.subtitle_label += ' → ' + sizeof_fmt(result_item.new_size)
         else:
             result_item.subtitle_label = error_message
 
@@ -282,6 +282,7 @@ class CurtailWindow(Adw.ApplicationWindow):
         return final_filenames
 
     def clean_filename(self, filename):
+        filename = str(filename)
         if filename.startswith('file://'):  # drag&drop
             filename = filename[7:]  # remove 'file://'
             filename = unquote(filename)  # remove %20
@@ -362,7 +363,7 @@ class CurtailWindow(Adw.ApplicationWindow):
                     license_type=Gtk.License.GPL_3_0,
                     website='https://github.com/Huluti/Curtail',
                     issue_url='https://github.com/Huluti/Curtail/issues/new',
-                    version='1.8.0',
+                    version='1.9.1',
                     developers=[
                         'Hugo Posnic https://github.com/Huluti'
                     ],
